@@ -5,13 +5,13 @@ pub mod merge_ff;
 pub mod merge_rebase;
 pub mod rename;
 
-use super::{
-	remotes::get_default_remote_in_repo, utils::bytes2string,
-	RepoPath,
-};
+use super::{utils::bytes2string, RepoPath};
 use crate::{
 	error::{Error, Result},
-	sync::{repository::repo, utils::get_head_repo, CommitId},
+	sync::{
+		remotes::get_default_remote_for_push_in_repo,
+		repository::repo, utils::get_head_repo, CommitId,
+	},
 };
 use git2::{Branch, BranchType, Repository};
 use scopetime::scope_time;
@@ -33,18 +33,15 @@ pub(crate) fn get_branch_name_repo(
 ) -> Result<String> {
 	scope_time!("get_branch_name_repo");
 
-	let iter = repo.branches(None)?;
-
-	for b in iter {
-		let b = b?;
-
-		if b.0.is_head() {
-			let name = b.0.name()?.unwrap_or("");
-			return Ok(name.into());
+	let head_ref = repo.head().map_err(|e| {
+		if e.code() == git2::ErrorCode::UnbornBranch {
+			Error::NoHead
+		} else {
+			e.into()
 		}
-	}
+	})?;
 
-	Err(Error::NoHead)
+	bytes2string(head_ref.shorthand_bytes())
 }
 
 ///
@@ -212,7 +209,7 @@ pub struct BranchCompare {
 }
 
 ///
-pub(crate) fn branch_set_upstream(
+pub(crate) fn branch_set_upstream_after_push(
 	repo: &Repository,
 	branch_name: &str,
 ) -> Result<()> {
@@ -222,7 +219,7 @@ pub(crate) fn branch_set_upstream(
 		repo.find_branch(branch_name, BranchType::Local)?;
 
 	if branch.upstream().is_err() {
-		let remote = get_default_remote_in_repo(repo)?;
+		let remote = get_default_remote_for_push_in_repo(repo)?;
 		let upstream_name = format!("{remote}/{branch_name}");
 		branch.set_upstream(Some(upstream_name.as_str()))?;
 	}
@@ -387,7 +384,7 @@ pub fn checkout_remote_branch(
 	if let Err(e) = repo.checkout_head(Some(
 		git2::build::CheckoutBuilder::new().force(),
 	)) {
-		// This is safe beacuse cur_ref was just found
+		// This is safe because cur_ref was just found
 		repo.set_head(bytes2string(cur_ref.name_bytes())?.as_str())?;
 		return Err(Error::Git(e));
 	}
