@@ -1,13 +1,18 @@
 //! credentials git helper
 
 use super::{
-	remotes::get_default_remote_in_repo, repository::repo, RepoPath,
+	remotes::{
+		get_default_remote_for_push_in_repo,
+		get_default_remote_in_repo,
+	},
+	repository::repo,
+	RepoPath,
 };
 use crate::error::{Error, Result};
 use git2::CredentialHelper;
 
 /// basic Authentication Credentials
-#[derive(Debug, Clone, Default, PartialEq)]
+#[derive(Debug, Clone, Default, PartialEq, Eq)]
 pub struct BasicAuthCredential {
 	///
 	pub username: Option<String>,
@@ -43,6 +48,22 @@ pub fn need_username_password(repo_path: &RepoPath) -> Result<bool> {
 	Ok(is_http)
 }
 
+/// know if username and password are needed for this url
+pub fn need_username_password_for_push(
+	repo_path: &RepoPath,
+) -> Result<bool> {
+	let repo = repo(repo_path)?;
+	let remote = repo
+		.find_remote(&get_default_remote_for_push_in_repo(&repo)?)?;
+	let url = remote
+		.pushurl()
+		.or_else(|| remote.url())
+		.ok_or(Error::UnknownRemote)?
+		.to_owned();
+	let is_http = url.starts_with("http");
+	Ok(is_http)
+}
+
 /// extract username and password
 pub fn extract_username_password(
 	repo_path: &RepoPath,
@@ -71,20 +92,49 @@ pub fn extract_username_password(
 	})
 }
 
+/// extract username and password
+pub fn extract_username_password_for_push(
+	repo_path: &RepoPath,
+) -> Result<BasicAuthCredential> {
+	let repo = repo(repo_path)?;
+	let url = repo
+		.find_remote(&get_default_remote_for_push_in_repo(&repo)?)?
+		.url()
+		.ok_or(Error::UnknownRemote)?
+		.to_owned();
+	let mut helper = CredentialHelper::new(&url);
+
+	//TODO: look at Cred::credential_helper,
+	//if the username is in the url we need to set it here,
+	//I dont think `config` will pick it up
+
+	if let Ok(config) = repo.config() {
+		helper.config(&config);
+	}
+
+	Ok(match helper.execute() {
+		Some((username, password)) => {
+			BasicAuthCredential::new(Some(username), Some(password))
+		}
+		None => extract_cred_from_url(&url),
+	})
+}
+
 /// extract credentials from url
 pub fn extract_cred_from_url(url: &str) -> BasicAuthCredential {
-	if let Ok(url) = url::Url::parse(url) {
-		BasicAuthCredential::new(
-			if url.username() == "" {
-				None
-			} else {
-				Some(url.username().to_owned())
-			},
-			url.password().map(std::borrow::ToOwned::to_owned),
-		)
-	} else {
-		BasicAuthCredential::new(None, None)
-	}
+	url::Url::parse(url).map_or_else(
+		|_| BasicAuthCredential::new(None, None),
+		|url| {
+			BasicAuthCredential::new(
+				if url.username() == "" {
+					None
+				} else {
+					Some(url.username().to_owned())
+				},
+				url.password().map(std::borrow::ToOwned::to_owned),
+			)
+		},
+	)
 }
 
 #[cfg(test)]
@@ -171,8 +221,6 @@ mod tests {
 		let repo_path: &RepoPath =
 			&root.as_os_str().to_str().unwrap().into();
 
-		//TODO:
-		// env::set_current_dir(repo_path).unwrap();
 		repo.remote(DEFAULT_REMOTE_NAME, "http://user@github.com")
 			.unwrap();
 
@@ -187,8 +235,6 @@ mod tests {
 		let repo_path: &RepoPath =
 			&root.as_os_str().to_str().unwrap().into();
 
-		//TODO:
-		// env::set_current_dir(repo_path).unwrap();
 		repo.remote(DEFAULT_REMOTE_NAME, "git@github.com:user/repo")
 			.unwrap();
 
@@ -224,9 +270,6 @@ mod tests {
 		let repo_path: &RepoPath =
 			&root.as_os_str().to_str().unwrap().into();
 
-		//TODO:
-		// env::set_current_dir(repo_path).unwrap();
-
 		need_username_password(repo_path).unwrap();
 	}
 
@@ -238,8 +281,6 @@ mod tests {
 		let repo_path: &RepoPath =
 			&root.as_os_str().to_str().unwrap().into();
 
-		//TODO:
-		// env::set_current_dir(repo_path).unwrap();
 		repo.remote(
 			DEFAULT_REMOTE_NAME,
 			"http://user:pass@github.com",
@@ -263,8 +304,6 @@ mod tests {
 		let repo_path: &RepoPath =
 			&root.as_os_str().to_str().unwrap().into();
 
-		//TODO:
-		// env::set_current_dir(repo_path).unwrap();
 		repo.remote(DEFAULT_REMOTE_NAME, "http://user@github.com")
 			.unwrap();
 
@@ -284,9 +323,6 @@ mod tests {
 		let repo_path: &RepoPath =
 			&root.as_os_str().to_str().unwrap().into();
 
-		//TODO: not needed anymore?
-		// env::set_current_dir(repo_path).unwrap();
-
 		extract_username_password(repo_path).unwrap();
 	}
 }
