@@ -5,7 +5,7 @@
 
 pub mod blame;
 pub mod branch;
-mod commit;
+pub mod commit;
 mod commit_details;
 pub mod commit_files;
 mod commit_filter;
@@ -25,6 +25,7 @@ pub mod remotes;
 mod repository;
 mod reset;
 mod reword;
+pub mod sign;
 mod staging;
 mod stash;
 mod state;
@@ -65,7 +66,8 @@ pub use config::{
 pub use diff::get_diff_commit;
 pub use git2::BranchType;
 pub use hooks::{
-	hooks_commit_msg, hooks_post_commit, hooks_pre_commit, HookResult,
+	hooks_commit_msg, hooks_post_commit, hooks_pre_commit,
+	hooks_prepare_commit_msg, HookResult, PrepareCommitMsgSource,
 };
 pub use hunks::{reset_hunk, stage_hunk, unstage_hunk};
 pub use ignore::add_to_ignore;
@@ -77,8 +79,8 @@ pub use merge::{
 };
 pub use rebase::rebase_branch;
 pub use remotes::{
-	get_default_remote, get_remotes, push::AsyncProgress,
-	tags::PushTagsProgress,
+	get_default_remote, get_default_remote_for_push, get_remotes,
+	push::AsyncProgress, tags::PushTagsProgress,
 };
 pub(crate) use repository::repo;
 pub use repository::{RepoPath, RepoPathRef};
@@ -317,7 +319,7 @@ mod tests {
 		eprintln!("\n----\n{cmd}");
 	}
 
-	/// helper to fetch commmit details using log walker
+	/// helper to fetch commit details using log walker
 	pub fn get_commit_ids(
 		r: &Repository,
 		max_count: usize,
