@@ -2,23 +2,23 @@ use crate::{
 	accessors,
 	cmdbar::CommandBar,
 	components::{
-		command_pump, event_pump, AppOption, BlameFileComponent,
-		BranchListComponent, CommandInfo, CommitComponent,
-		CompareCommitsComponent, Component, ConfirmComponent,
-		CreateBranchComponent, DrawableComponent,
-		ExternalEditorComponent, FetchComponent, FileRevlogComponent,
-		FuzzyFindPopup, FuzzyFinderTarget, HelpComponent,
-		InspectCommitComponent, LogSearchPopupComponent,
-		MsgComponent, OptionsPopupComponent, PullComponent,
-		PushComponent, PushTagsComponent, RenameBranchComponent,
-		ResetPopupComponent, RevisionFilesPopup, StashMsgComponent,
-		SubmodulesListComponent, TagCommitComponent,
-		TagListComponent,
+		command_pump, event_pump, CommandInfo, Component,
+		DrawableComponent, FuzzyFinderTarget,
 	},
 	input::{Input, InputEvent, InputState},
 	keys::{key_match, KeyConfig, SharedKeyConfig},
 	options::{Options, SharedOptions},
 	popup_stack::PopupStack,
+	popups::{
+		AppOption, BlameFilePopup, BranchListPopup, CommitPopup,
+		CompareCommitsPopup, ConfirmPopup, CreateBranchPopup,
+		ExternalEditorPopup, FetchPopup, FileRevlogPopup,
+		FuzzyFindPopup, HelpPopup, InspectCommitPopup,
+		LogSearchPopupPopup, MsgPopup, OptionsPopup, PullPopup,
+		PushPopup, PushTagsPopup, RenameBranchPopup, ResetPopup,
+		RevisionFilesPopup, StashMsgPopup, SubmodulesListPopup,
+		TagCommitPopup, TagListPopup,
+	},
 	queue::{
 		Action, AppTabs, InternalEvent, NeedsUpdate, Queue,
 		StackablePopupOpen,
@@ -26,18 +26,22 @@ use crate::{
 	setup_popups,
 	strings::{self, ellipsis_trim_start, order},
 	tabs::{FilesTab, Revlog, StashList, Stashing, Status},
+	try_or_popup,
 	ui::style::{SharedTheme, Theme},
 	AsyncAppNotification, AsyncNotification,
 };
 use anyhow::{bail, Result};
 use asyncgit::{
-	sync::{self, utils::repo_work_dir, RepoPath, RepoPathRef},
+	sync::{
+		self,
+		utils::{repo_work_dir, undo_last_commit},
+		RepoPath, RepoPathRef,
+	},
 	AsyncGitNotification, PushType,
 };
 use crossbeam_channel::Sender;
 use crossterm::event::{Event, KeyEvent};
 use ratatui::{
-	backend::Backend,
 	layout::{
 		Alignment, Constraint, Direction, Layout, Margin, Rect,
 	},
@@ -63,31 +67,31 @@ pub enum QuitState {
 pub struct App {
 	repo: RepoPathRef,
 	do_quit: QuitState,
-	help: HelpComponent,
-	msg: MsgComponent,
-	reset: ConfirmComponent,
-	commit: CommitComponent,
-	blame_file_popup: BlameFileComponent,
-	file_revlog_popup: FileRevlogComponent,
-	stashmsg_popup: StashMsgComponent,
-	inspect_commit_popup: InspectCommitComponent,
-	compare_commits_popup: CompareCommitsComponent,
-	external_editor_popup: ExternalEditorComponent,
+	help_popup: HelpPopup,
+	msg_popup: MsgPopup,
+	confirm_popup: ConfirmPopup,
+	commit_popup: CommitPopup,
+	blame_file_popup: BlameFilePopup,
+	file_revlog_popup: FileRevlogPopup,
+	stashmsg_popup: StashMsgPopup,
+	inspect_commit_popup: InspectCommitPopup,
+	compare_commits_popup: CompareCommitsPopup,
+	external_editor_popup: ExternalEditorPopup,
 	revision_files_popup: RevisionFilesPopup,
 	fuzzy_find_popup: FuzzyFindPopup,
-	log_search_popup: LogSearchPopupComponent,
-	push_popup: PushComponent,
-	push_tags_popup: PushTagsComponent,
-	pull_popup: PullComponent,
-	fetch_popup: FetchComponent,
-	tag_commit_popup: TagCommitComponent,
-	create_branch_popup: CreateBranchComponent,
-	rename_branch_popup: RenameBranchComponent,
-	select_branch_popup: BranchListComponent,
-	options_popup: OptionsPopupComponent,
-	submodule_popup: SubmodulesListComponent,
-	tags_popup: TagListComponent,
-	reset_popup: ResetPopupComponent,
+	log_search_popup: LogSearchPopupPopup,
+	push_popup: PushPopup,
+	push_tags_popup: PushTagsPopup,
+	pull_popup: PullPopup,
+	fetch_popup: FetchPopup,
+	tag_commit_popup: TagCommitPopup,
+	create_branch_popup: CreateBranchPopup,
+	rename_branch_popup: RenameBranchPopup,
+	select_branch_popup: BranchListPopup,
+	options_popup: OptionsPopup,
+	submodule_popup: SubmodulesListPopup,
+	tags_popup: TagListPopup,
+	reset_popup: ResetPopup,
 	cmdbar: RefCell<CommandBar>,
 	tab: usize,
 	revlog: Revlog,
@@ -108,14 +112,41 @@ pub struct App {
 	file_to_open: Option<String>,
 }
 
+pub struct Environment {
+	pub queue: Queue,
+	pub theme: SharedTheme,
+	pub key_config: SharedKeyConfig,
+	pub repo: RepoPathRef,
+	pub options: SharedOptions,
+	pub sender_git: Sender<AsyncGitNotification>,
+	pub sender_app: Sender<AsyncAppNotification>,
+}
+
+/// The need to construct a "whatever" environment only arises in testing right now
+#[cfg(test)]
+impl Environment {
+	pub fn test_env() -> Self {
+		use crossbeam_channel::unbounded;
+		Self {
+			queue: Queue::new(),
+			theme: Default::default(),
+			key_config: Default::default(),
+			repo: RefCell::new(RepoPath::Path(Default::default())),
+			options: Rc::new(RefCell::new(Options::test_env())),
+			sender_git: unbounded().0,
+			sender_app: unbounded().0,
+		}
+	}
+}
+
 // public interface
 impl App {
 	///
 	#[allow(clippy::too_many_lines)]
 	pub fn new(
 		repo: RepoPathRef,
-		sender: &Sender<AsyncGitNotification>,
-		sender_app: &Sender<AsyncAppNotification>,
+		sender_git: Sender<AsyncGitNotification>,
+		sender_app: Sender<AsyncAppNotification>,
 		input: Input,
 		theme: Theme,
 		key_config: KeyConfig,
@@ -125,219 +156,66 @@ impl App {
 		let repo_path_text =
 			repo_work_dir(&repo.borrow()).unwrap_or_default();
 
-		let queue = Queue::new();
-		let theme = Rc::new(theme);
-		let key_config = Rc::new(key_config);
-		let options = Options::new(repo.clone());
+		let env = Environment {
+			queue: Queue::new(),
+			theme: Rc::new(theme),
+			key_config: Rc::new(key_config),
+			options: Options::new(repo.clone()),
+			repo,
+			sender_git,
+			sender_app,
+		};
 
-		let tab = options.borrow().current_tab();
+		let tab = env.options.borrow().current_tab();
 
 		let mut app = Self {
 			input,
-			reset: ConfirmComponent::new(
-				queue.clone(),
-				theme.clone(),
-				key_config.clone(),
-			),
-			commit: CommitComponent::new(
-				repo.clone(),
-				queue.clone(),
-				theme.clone(),
-				key_config.clone(),
-				options.clone(),
-			),
-			blame_file_popup: BlameFileComponent::new(
-				&repo,
-				&queue,
-				sender,
-				&strings::blame_title(&key_config),
-				theme.clone(),
-				key_config.clone(),
-			),
-			file_revlog_popup: FileRevlogComponent::new(
-				&repo,
-				&queue,
-				sender,
-				theme.clone(),
-				key_config.clone(),
-				options.clone(),
-			),
-			revision_files_popup: RevisionFilesPopup::new(
-				repo.clone(),
-				&queue,
-				sender_app,
-				sender.clone(),
-				theme.clone(),
-				key_config.clone(),
-			),
-			stashmsg_popup: StashMsgComponent::new(
-				repo.clone(),
-				queue.clone(),
-				theme.clone(),
-				key_config.clone(),
-			),
-			inspect_commit_popup: InspectCommitComponent::new(
-				&repo,
-				&queue,
-				sender,
-				theme.clone(),
-				key_config.clone(),
-				options.clone(),
-			),
-			compare_commits_popup: CompareCommitsComponent::new(
-				&repo,
-				&queue,
-				sender,
-				theme.clone(),
-				key_config.clone(),
-				options.clone(),
-			),
-			external_editor_popup: ExternalEditorComponent::new(
-				theme.clone(),
-				key_config.clone(),
-			),
-			push_popup: PushComponent::new(
-				&repo,
-				&queue,
-				sender,
-				theme.clone(),
-				key_config.clone(),
-			),
-			push_tags_popup: PushTagsComponent::new(
-				&repo,
-				&queue,
-				sender,
-				theme.clone(),
-				key_config.clone(),
-			),
-			reset_popup: ResetPopupComponent::new(
-				&queue,
-				&repo,
-				theme.clone(),
-				key_config.clone(),
-			),
-			pull_popup: PullComponent::new(
-				&repo,
-				&queue,
-				sender,
-				theme.clone(),
-				key_config.clone(),
-			),
-			fetch_popup: FetchComponent::new(
-				repo.clone(),
-				&queue,
-				sender,
-				theme.clone(),
-				key_config.clone(),
-			),
-			tag_commit_popup: TagCommitComponent::new(
-				repo.clone(),
-				queue.clone(),
-				theme.clone(),
-				key_config.clone(),
-			),
-			create_branch_popup: CreateBranchComponent::new(
-				repo.clone(),
-				queue.clone(),
-				theme.clone(),
-				key_config.clone(),
-			),
-			rename_branch_popup: RenameBranchComponent::new(
-				repo.clone(),
-				queue.clone(),
-				theme.clone(),
-				key_config.clone(),
-			),
-			select_branch_popup: BranchListComponent::new(
-				repo.clone(),
-				queue.clone(),
-				theme.clone(),
-				key_config.clone(),
-			),
-			tags_popup: TagListComponent::new(
-				repo.clone(),
-				&queue,
-				sender,
-				theme.clone(),
-				key_config.clone(),
-			),
-			options_popup: OptionsPopupComponent::new(
-				&queue,
-				theme.clone(),
-				key_config.clone(),
-				options.clone(),
-			),
-			submodule_popup: SubmodulesListComponent::new(
-				repo.clone(),
-				&queue,
-				theme.clone(),
-				key_config.clone(),
-			),
-			log_search_popup: LogSearchPopupComponent::new(
-				repo.clone(),
-				&queue,
-				theme.clone(),
-				key_config.clone(),
-			),
-			fuzzy_find_popup: FuzzyFindPopup::new(
-				&queue,
-				theme.clone(),
-				key_config.clone(),
+			confirm_popup: ConfirmPopup::new(&env),
+			commit_popup: CommitPopup::new(&env),
+			blame_file_popup: BlameFilePopup::new(
+				&env,
+				&strings::blame_title(&env.key_config),
 			),
+			file_revlog_popup: FileRevlogPopup::new(&env),
+			revision_files_popup: RevisionFilesPopup::new(&env),
+			stashmsg_popup: StashMsgPopup::new(&env),
+			inspect_commit_popup: InspectCommitPopup::new(&env),
+			compare_commits_popup: CompareCommitsPopup::new(&env),
+			external_editor_popup: ExternalEditorPopup::new(&env),
+			push_popup: PushPopup::new(&env),
+			push_tags_popup: PushTagsPopup::new(&env),
+			reset_popup: ResetPopup::new(&env),
+			pull_popup: PullPopup::new(&env),
+			fetch_popup: FetchPopup::new(&env),
+			tag_commit_popup: TagCommitPopup::new(&env),
+			create_branch_popup: CreateBranchPopup::new(&env),
+			rename_branch_popup: RenameBranchPopup::new(&env),
+			select_branch_popup: BranchListPopup::new(&env),
+			tags_popup: TagListPopup::new(&env),
+			options_popup: OptionsPopup::new(&env),
+			submodule_popup: SubmodulesListPopup::new(&env),
+			log_search_popup: LogSearchPopupPopup::new(&env),
+			fuzzy_find_popup: FuzzyFindPopup::new(&env),
 			do_quit: QuitState::None,
 			cmdbar: RefCell::new(CommandBar::new(
-				theme.clone(),
-				key_config.clone(),
+				env.theme.clone(),
+				env.key_config.clone(),
 			)),
-			help: HelpComponent::new(
-				theme.clone(),
-				key_config.clone(),
-			),
-			msg: MsgComponent::new(theme.clone(), key_config.clone()),
-			revlog: Revlog::new(
-				&repo,
-				&queue,
-				sender,
-				theme.clone(),
-				key_config.clone(),
-			),
-			status_tab: Status::new(
-				repo.clone(),
-				&queue,
-				sender,
-				theme.clone(),
-				key_config.clone(),
-				options.clone(),
-			),
-			stashing_tab: Stashing::new(
-				&repo,
-				sender,
-				&queue,
-				theme.clone(),
-				key_config.clone(),
-			),
-			stashlist_tab: StashList::new(
-				repo.clone(),
-				&queue,
-				theme.clone(),
-				key_config.clone(),
-			),
-			files_tab: FilesTab::new(
-				repo.clone(),
-				sender_app,
-				sender.clone(),
-				&queue,
-				theme.clone(),
-				key_config.clone(),
-			),
+			help_popup: HelpPopup::new(&env),
+			msg_popup: MsgPopup::new(&env),
+			revlog: Revlog::new(&env),
+			status_tab: Status::new(&env),
+			stashing_tab: Stashing::new(&env),
+			stashlist_tab: StashList::new(&env),
+			files_tab: FilesTab::new(&env),
 			tab: 0,
-			queue,
-			theme,
-			options,
-			key_config,
+			queue: env.queue,
+			theme: env.theme,
+			options: env.options,
+			key_config: env.key_config,
 			requires_redraw: Cell::new(false),
 			file_to_open: None,
-			repo,
+			repo: env.repo,
 			repo_path_text,
 			popup_stack: PopupStack::default(),
 		};
@@ -348,7 +226,7 @@ impl App {
 	}
 
 	///
-	pub fn draw<B: Backend>(&self, f: &mut Frame<B>) -> Result<()> {
+	pub fn draw(&self, f: &mut Frame) -> Result<()> {
 		let fsize = f.size();
 
 		self.cmdbar.borrow_mut().refresh_width(fsize.width);
@@ -466,21 +344,21 @@ impl App {
 			if matches!(polling_state, InputState::Paused) {
 				let result =
 					if let Some(path) = self.file_to_open.take() {
-						ExternalEditorComponent::open_file_in_editor(
+						ExternalEditorPopup::open_file_in_editor(
 							&self.repo.borrow(),
 							Path::new(&path),
 						)
 					} else {
 						let changes =
 							self.status_tab.get_files_changes()?;
-						self.commit.show_editor(changes)
+						self.commit_popup.show_editor(changes)
 					};
 
 				if let Err(e) = result {
 					let msg =
 						format!("failed to launch editor:\n{e}");
 					log::error!("{}", msg.as_str());
-					self.msg.show_error(msg.as_str())?;
+					self.msg_popup.show_error(msg.as_str())?;
 				}
 
 				self.requires_redraw.set(true);
@@ -496,7 +374,7 @@ impl App {
 	pub fn update(&mut self) -> Result<()> {
 		log::trace!("update");
 
-		self.commit.update();
+		self.commit_popup.update();
 		self.status_tab.update()?;
 		self.revlog.update()?;
 		self.files_tab.update()?;
@@ -520,7 +398,6 @@ impl App {
 			self.status_tab.update_git(ev)?;
 			self.stashing_tab.update_git(ev)?;
 			self.revlog.update_git(ev)?;
-			self.blame_file_popup.update_git(ev)?;
 			self.file_revlog_popup.update_git(ev)?;
 			self.inspect_commit_popup.update_git(ev)?;
 			self.compare_commits_popup.update_git(ev)?;
@@ -532,6 +409,7 @@ impl App {
 		}
 
 		self.files_tab.update_async(ev)?;
+		self.blame_file_popup.update_async(ev)?;
 		self.revision_files_popup.update(ev)?;
 		self.tags_popup.update(ev);
 
@@ -590,9 +468,9 @@ impl App {
 		[
 			log_search_popup,
 			fuzzy_find_popup,
-			msg,
-			reset,
-			commit,
+			msg_popup,
+			confirm_popup,
+			commit_popup,
 			blame_file_popup,
 			file_revlog_popup,
 			stashmsg_popup,
@@ -604,15 +482,15 @@ impl App {
 			pull_popup,
 			fetch_popup,
 			tag_commit_popup,
+			reset_popup,
 			create_branch_popup,
 			rename_branch_popup,
 			select_branch_popup,
 			revision_files_popup,
 			submodule_popup,
 			tags_popup,
-			reset_popup,
 			options_popup,
-			help,
+			help_popup,
 			revlog,
 			status_tab,
 			files_tab,
@@ -624,9 +502,9 @@ impl App {
 	setup_popups!(
 		self,
 		[
-			commit,
+			commit_popup,
 			stashmsg_popup,
-			help,
+			help_popup,
 			inspect_commit_popup,
 			compare_commits_popup,
 			blame_file_popup,
@@ -647,8 +525,8 @@ impl App {
 			pull_popup,
 			fetch_popup,
 			options_popup,
-			reset,
-			msg
+			confirm_popup,
+			msg_popup
 		]
 	);
 
@@ -740,8 +618,8 @@ impl App {
 	}
 
 	fn update_commands(&mut self) {
-		if self.help.is_visible() {
-			self.help.set_cmds(self.commands(true));
+		if self.help_popup.is_visible() {
+			self.help_popup.set_cmds(self.commands(true));
 		}
 		self.cmdbar.borrow_mut().set_cmds(self.commands(false));
 	}
@@ -824,23 +702,23 @@ impl App {
 				self.process_confirmed_action(action, &mut flags)?;
 			}
 			InternalEvent::ConfirmAction(action) => {
-				self.reset.open(action)?;
+				self.confirm_popup.open(action)?;
 				flags.insert(NeedsUpdate::COMMANDS);
 			}
 			InternalEvent::ShowErrorMsg(msg) => {
-				self.msg.show_error(msg.as_str())?;
+				self.msg_popup.show_error(msg.as_str())?;
 				flags
 					.insert(NeedsUpdate::ALL | NeedsUpdate::COMMANDS);
 			}
 			InternalEvent::ShowInfoMsg(msg) => {
-				self.msg.show_info(msg.as_str())?;
+				self.msg_popup.show_info(msg.as_str())?;
 				flags
 					.insert(NeedsUpdate::ALL | NeedsUpdate::COMMANDS);
 			}
 			InternalEvent::Update(u) => flags.insert(u),
-			InternalEvent::OpenCommit => self.commit.show()?,
+			InternalEvent::OpenCommit => self.commit_popup.show()?,
 			InternalEvent::RewordCommit(id) => {
-				self.commit.open(Some(id))?;
+				self.commit_popup.open(Some(id))?;
 			}
 			InternalEvent::PopupStashing(opts) => {
 				self.stashmsg_popup.options(opts);
@@ -1076,6 +954,13 @@ impl App {
 			Action::AbortRebase => {
 				self.status_tab.abort_rebase();
 			}
+			Action::UndoCommit => {
+				try_or_popup!(
+					self,
+					"undo commit failed:",
+					undo_last_commit(&self.repo.borrow())
+				);
+			}
 		};
 
 		flags.insert(NeedsUpdate::ALL);
@@ -1184,7 +1069,7 @@ impl App {
 	}
 
 	//TODO: make this dynamic
-	fn draw_top_bar<B: Backend>(&self, f: &mut Frame<B>, r: Rect) {
+	fn draw_top_bar(&self, f: &mut Frame, r: Rect) {
 		const DIVIDER_PAD_SPACES: usize = 2;
 		const SIDE_PADS: usize = 2;
 		const MARGIN_LEFT_AND_RIGHT: usize = 2;
@@ -1246,7 +1131,7 @@ impl App {
 					&self.repo_path_text,
 					text_area.width as usize,
 				),
-				self.theme.title(true),
+				self.theme.title(false),
 			)]))
 			.alignment(Alignment::Right),
 			text_area,
