@@ -1,5 +1,6 @@
 use super::utils::logitems::{ItemBatch, LogEntry};
 use crate::{
+	app::Environment,
 	components::{
 		utils::string_width_align, CommandBlocking, CommandInfo,
 		Component, DrawableComponent, EventState, ScrollType,
@@ -21,7 +22,6 @@ use crossterm::event::Event;
 use indexmap::IndexSet;
 use itertools::Itertools;
 use ratatui::{
-	backend::Backend,
 	layout::{Alignment, Rect},
 	style::Style,
 	text::{Line, Span},
@@ -29,8 +29,8 @@ use ratatui::{
 	Frame,
 };
 use std::{
-	borrow::Cow, cell::Cell, cmp, collections::BTreeMap,
-	convert::TryFrom, rc::Rc, time::Instant,
+	borrow::Cow, cell::Cell, cmp, collections::BTreeMap, rc::Rc,
+	time::Instant,
 };
 
 const ELEMENTS_PER_LINE: usize = 9;
@@ -59,15 +59,9 @@ pub struct CommitList {
 
 impl CommitList {
 	///
-	pub fn new(
-		repo: RepoPathRef,
-		title: &str,
-		theme: SharedTheme,
-		queue: Queue,
-		key_config: SharedKeyConfig,
-	) -> Self {
+	pub fn new(env: &Environment, title: &str) -> Self {
 		Self {
-			repo,
+			repo: env.repo.clone(),
 			items: ItemBatch::default(),
 			marked: Vec::with_capacity(2),
 			selection: 0,
@@ -80,9 +74,9 @@ impl CommitList {
 			remote_branches: BTreeMap::default(),
 			current_size: Cell::new(None),
 			scroll_top: Cell::new(0),
-			theme,
-			queue,
-			key_config,
+			theme: env.theme.clone(),
+			queue: env.queue.clone(),
+			key_config: env.key_config.clone(),
 			title: title.into(),
 		}
 	}
@@ -156,11 +150,7 @@ impl CommitList {
 					marked.windows(2).all(|w| w[0].0 + 1 == w[1].0);
 
 				let yank = if marked_consecutive {
-					format!(
-						"{}^..{}",
-						first.1.to_string(),
-						last.1.to_string()
-					)
+					format!("{}^..{}", first.1, last.1)
 				} else {
 					marked
 						.iter()
@@ -253,8 +243,7 @@ impl CommitList {
 		//note: set highlights to none if there is no highlight
 		self.highlights = if highlighting
 			.as_ref()
-			.map(|set| set.is_empty())
-			.unwrap_or_default()
+			.is_some_and(|set| set.is_empty())
 		{
 			None
 		} else {
@@ -307,7 +296,6 @@ impl CommitList {
 		self.current_size.get()
 	}
 
-	#[allow(clippy::missing_const_for_fn)]
 	fn selection_max(&self) -> usize {
 		self.commits.len().saturating_sub(1)
 	}
@@ -675,7 +663,6 @@ impl CommitList {
 		})
 	}
 
-	#[allow(clippy::missing_const_for_fn)]
 	fn relative_selection(&self) -> usize {
 		self.selection.saturating_sub(self.items.index_offset())
 	}
@@ -723,8 +710,7 @@ impl CommitList {
 
 		self.highlights
 			.as_ref()
-			.map(|highlights| highlights.contains(&commit))
-			.unwrap_or_default()
+			.is_some_and(|highlights| highlights.contains(&commit))
 	}
 
 	fn needs_data(&self, idx: usize, idx_max: usize) -> bool {
@@ -754,8 +740,7 @@ impl CommitList {
 		let index_in_sync = self
 			.items
 			.index_offset_raw()
-			.map(|index| want_min == index)
-			.unwrap_or_default();
+			.is_some_and(|index| want_min == index);
 
 		if !index_in_sync || !self.is_list_in_sync() || force {
 			let commits = sync::get_commits_info(
@@ -784,11 +769,7 @@ impl CommitList {
 }
 
 impl DrawableComponent for CommitList {
-	fn draw<B: Backend>(
-		&self,
-		f: &mut Frame<B>,
-		area: Rect,
-	) -> Result<()> {
+	fn draw(&self, f: &mut Frame, area: Rect) -> Result<()> {
 		let current_size = (
 			area.width.saturating_sub(2),
 			area.height.saturating_sub(2),
