@@ -4,6 +4,7 @@ use super::{
 	Direction, DrawableComponent, HorizontalScrollType, ScrollType,
 };
 use crate::{
+	app::Environment,
 	components::{CommandInfo, Component, EventState},
 	keys::{key_match, SharedKeyConfig},
 	options::SharedOptions,
@@ -22,7 +23,6 @@ use asyncgit::{
 use bytesize::ByteSize;
 use crossterm::event::Event;
 use ratatui::{
-	backend::Backend,
 	layout::Rect,
 	symbols,
 	text::{Line, Span},
@@ -123,17 +123,10 @@ pub struct DiffComponent {
 
 impl DiffComponent {
 	///
-	pub fn new(
-		repo: RepoPathRef,
-		queue: Queue,
-		theme: SharedTheme,
-		key_config: SharedKeyConfig,
-		is_immutable: bool,
-		options: SharedOptions,
-	) -> Self {
+	pub fn new(env: &Environment, is_immutable: bool) -> Self {
 		Self {
 			focused: false,
-			queue,
+			queue: env.queue.clone(),
 			current: Current::default(),
 			pending: false,
 			selected_hunk: None,
@@ -143,19 +136,16 @@ impl DiffComponent {
 			selection: Selection::Single(0),
 			vertical_scroll: VerticalScroll::new(),
 			horizontal_scroll: HorizontalScroll::new(),
-			theme,
-			key_config,
+			theme: env.theme.clone(),
+			key_config: env.key_config.clone(),
 			is_immutable,
-			repo,
-			options,
+			repo: env.repo.clone(),
+			options: env.options.clone(),
 		}
 	}
 	///
 	fn can_scroll(&self) -> bool {
-		self.diff
-			.as_ref()
-			.map(|diff| diff.lines > 1)
-			.unwrap_or_default()
+		self.diff.as_ref().is_some_and(|diff| diff.lines > 1)
 	}
 	///
 	pub fn current(&self) -> (String, bool) {
@@ -462,7 +452,7 @@ impl DiffComponent {
 
 		let content =
 			if !is_content_line && line.content.as_ref().is_empty() {
-				String::from(strings::symbol::LINE_BREAK)
+				theme.line_break()
 			} else {
 				tabs_to_spaces(line.content.as_ref().to_string())
 			};
@@ -578,7 +568,7 @@ impl DiffComponent {
 
 	fn stage_lines(&self) {
 		if let Some(diff) = &self.diff {
-			//TODO: support untracked files aswell
+			//TODO: support untracked files as well
 			if !diff.untracked {
 				let selected_lines = self.selected_lines();
 
@@ -627,7 +617,6 @@ impl DiffComponent {
 		self.queue.push(InternalEvent::ConfirmAction(Action::Reset(
 			ResetItem {
 				path: self.current.path.clone(),
-				is_folder: false,
 			},
 		)));
 	}
@@ -692,11 +681,7 @@ impl DiffComponent {
 }
 
 impl DrawableComponent for DiffComponent {
-	fn draw<B: Backend>(
-		&self,
-		f: &mut Frame<B>,
-		r: Rect,
-	) -> Result<()> {
+	fn draw(&self, f: &mut Frame, r: Rect) -> Result<()> {
 		self.current_size.set((
 			r.width.saturating_sub(2),
 			r.height.saturating_sub(2),
@@ -958,3 +943,75 @@ impl Component for DiffComponent {
 		self.focused = focus;
 	}
 }
+
+#[cfg(test)]
+mod tests {
+	use super::*;
+	use crate::ui::style::Theme;
+	use std::io::Write;
+	use std::rc::Rc;
+	use tempfile::NamedTempFile;
+
+	#[test]
+	fn test_line_break() {
+		let diff_line = DiffLine {
+			content: "".into(),
+			line_type: DiffLineType::Add,
+			position: Default::default(),
+		};
+
+		{
+			let default_theme = Rc::new(Theme::default());
+
+			assert_eq!(
+				DiffComponent::get_line_to_add(
+					4,
+					&diff_line,
+					false,
+					false,
+					false,
+					&default_theme,
+					0
+				)
+				.spans
+				.last()
+				.unwrap(),
+				&Span::styled(
+					Cow::from("¶\n"),
+					default_theme
+						.diff_line(diff_line.line_type, false)
+				)
+			);
+		}
+
+		{
+			let mut file = NamedTempFile::new().unwrap();
+
+			writeln!(
+				file,
+				r#"
+(
+	line_break: Some("+")
+)
+"#
+			)
+			.unwrap();
+
+			let theme =
+				Rc::new(Theme::init(&file.path().to_path_buf()));
+
+			assert_eq!(
+				DiffComponent::get_line_to_add(
+					4, &diff_line, false, false, false, &theme, 0
+				)
+				.spans
+				.last()
+				.unwrap(),
+				&Span::styled(
+					Cow::from("+\n"),
+					theme.diff_line(diff_line.line_type, false)
+				)
+			);
+		}
+	}
+}
