@@ -34,8 +34,8 @@ impl From<&GituiKeyEvent> for KeyEvent {
 	}
 }
 
-#[derive(Clone, Patch)]
-#[patch_derive(Deserialize)]
+#[derive(Debug, Clone, Patch)]
+#[patch_derive(Deserialize, Debug)]
 pub struct KeysList {
 	pub tab_status: GituiKeyEvent,
 	pub tab_log: GituiKeyEvent,
@@ -85,9 +85,12 @@ pub struct KeysList {
 	pub log_tag_commit: GituiKeyEvent,
 	pub log_mark_commit: GituiKeyEvent,
 	pub log_checkout_commit: GituiKeyEvent,
-	pub log_reset_comit: GituiKeyEvent,
-	pub log_reword_comit: GituiKeyEvent,
+	pub log_reset_commit: GituiKeyEvent,
+	pub log_reword_commit: GituiKeyEvent,
+	pub log_find: GituiKeyEvent,
+	pub find_commit_sha: GituiKeyEvent,
 	pub commit_amend: GituiKeyEvent,
+	pub toggle_signoff: GituiKeyEvent,
 	pub toggle_verify: GituiKeyEvent,
 	pub copy: GituiKeyEvent,
 	pub create_branch: GituiKeyEvent,
@@ -96,6 +99,7 @@ pub struct KeysList {
 	pub delete_branch: GituiKeyEvent,
 	pub merge_branch: GituiKeyEvent,
 	pub rebase_branch: GituiKeyEvent,
+	pub reset_branch: GituiKeyEvent,
 	pub compare_commits: GituiKeyEvent,
 	pub tags: GituiKeyEvent,
 	pub delete_tag: GituiKeyEvent,
@@ -109,12 +113,16 @@ pub struct KeysList {
 	pub pull: GituiKeyEvent,
 	pub abort_merge: GituiKeyEvent,
 	pub undo_commit: GituiKeyEvent,
+	pub diff_hunk_next: GituiKeyEvent,
+	pub diff_hunk_prev: GituiKeyEvent,
 	pub stage_unstage_item: GituiKeyEvent,
 	pub tag_annotate: GituiKeyEvent,
 	pub view_submodules: GituiKeyEvent,
 	pub view_submodule_parent: GituiKeyEvent,
 	pub update_submodule: GituiKeyEvent,
 	pub commit_history_next: GituiKeyEvent,
+	pub commit: GituiKeyEvent,
+	pub newline: GituiKeyEvent,
 }
 
 #[rustfmt::skip]
@@ -169,9 +177,12 @@ impl Default for KeysList {
 			log_tag_commit: GituiKeyEvent::new(KeyCode::Char('t'),  KeyModifiers::empty()),
 			log_mark_commit: GituiKeyEvent::new(KeyCode::Char(' '),  KeyModifiers::empty()),
 			log_checkout_commit: GituiKeyEvent { code: KeyCode::Char('S'), modifiers: KeyModifiers::SHIFT },
-			log_reset_comit: GituiKeyEvent { code: KeyCode::Char('R'), modifiers: KeyModifiers::SHIFT },
-			log_reword_comit: GituiKeyEvent { code: KeyCode::Char('r'), modifiers: KeyModifiers::empty() },
+			log_reset_commit: GituiKeyEvent { code: KeyCode::Char('R'), modifiers: KeyModifiers::SHIFT },
+			log_reword_commit: GituiKeyEvent { code: KeyCode::Char('r'), modifiers: KeyModifiers::empty() },
+			log_find: GituiKeyEvent { code: KeyCode::Char('f'), modifiers: KeyModifiers::empty() },
+			find_commit_sha: GituiKeyEvent::new(KeyCode::Char('j'), KeyModifiers::CONTROL),
 			commit_amend: GituiKeyEvent::new(KeyCode::Char('a'),  KeyModifiers::CONTROL),
+			toggle_signoff: GituiKeyEvent::new(KeyCode::Char('s'),  KeyModifiers::CONTROL),
 			toggle_verify: GituiKeyEvent::new(KeyCode::Char('f'),  KeyModifiers::CONTROL),
 			copy: GituiKeyEvent::new(KeyCode::Char('y'),  KeyModifiers::empty()),
 			create_branch: GituiKeyEvent::new(KeyCode::Char('c'),  KeyModifiers::empty()),
@@ -180,6 +191,7 @@ impl Default for KeysList {
 			delete_branch: GituiKeyEvent::new(KeyCode::Char('D'),  KeyModifiers::SHIFT),
 			merge_branch: GituiKeyEvent::new(KeyCode::Char('m'),  KeyModifiers::empty()),
 			rebase_branch: GituiKeyEvent::new(KeyCode::Char('R'),  KeyModifiers::SHIFT),
+			reset_branch: GituiKeyEvent::new(KeyCode::Char('s'),  KeyModifiers::empty()),
 			compare_commits: GituiKeyEvent::new(KeyCode::Char('C'),  KeyModifiers::SHIFT),
 			tags: GituiKeyEvent::new(KeyCode::Char('T'),  KeyModifiers::SHIFT),
 			delete_tag: GituiKeyEvent::new(KeyCode::Char('D'),  KeyModifiers::SHIFT),
@@ -193,12 +205,16 @@ impl Default for KeysList {
 			open_file_tree: GituiKeyEvent::new(KeyCode::Char('F'),  KeyModifiers::SHIFT),
 			file_find: GituiKeyEvent::new(KeyCode::Char('f'),  KeyModifiers::empty()),
 			branch_find: GituiKeyEvent::new(KeyCode::Char('f'),  KeyModifiers::empty()),
+			diff_hunk_next: GituiKeyEvent::new(KeyCode::Char('n'),  KeyModifiers::empty()),
+			diff_hunk_prev: GituiKeyEvent::new(KeyCode::Char('p'),  KeyModifiers::empty()),
 			stage_unstage_item: GituiKeyEvent::new(KeyCode::Enter,  KeyModifiers::empty()),
 			tag_annotate: GituiKeyEvent::new(KeyCode::Char('a'),  KeyModifiers::CONTROL),
 			view_submodules: GituiKeyEvent::new(KeyCode::Char('S'),  KeyModifiers::SHIFT),
 			view_submodule_parent: GituiKeyEvent::new(KeyCode::Char('p'),  KeyModifiers::empty()),
 			update_submodule: GituiKeyEvent::new(KeyCode::Char('u'),  KeyModifiers::empty()),
 			commit_history_next: GituiKeyEvent::new(KeyCode::Char('n'),  KeyModifiers::CONTROL),
+			commit: GituiKeyEvent::new(KeyCode::Char('d'),  KeyModifiers::CONTROL),
+			newline: GituiKeyEvent::new(KeyCode::Enter,  KeyModifiers::empty()),
 		}
 	}
 }
@@ -207,8 +223,11 @@ impl KeysList {
 	pub fn init(file: PathBuf) -> Self {
 		let mut keys_list = Self::default();
 		if let Ok(f) = File::open(file) {
-			if let Ok(patch) = ron::de::from_reader(f) {
-				keys_list.apply(patch);
+			match ron::de::from_reader(f) {
+				Ok(patch) => keys_list.apply(patch),
+				Err(e) => {
+					log::error!("KeysList parse error: {e}");
+				}
 			}
 		}
 		keys_list
@@ -238,11 +257,12 @@ mod tests {
 
 		writeln!(
 			file,
-			r"
+			r#"
 (
-	move_down: Some(( code: Char('j'), modifiers: ( bits: 2,),)),
+	move_down: Some(( code: Char('j'), modifiers: "CONTROL")),
+	move_up: Some((code: Char('h'), modifiers: ""))
 )
-"
+"#
 		)
 		.unwrap();
 
@@ -256,5 +276,12 @@ mod tests {
 				KeyModifiers::CONTROL
 			)
 		);
+		assert_eq!(
+			keys.move_up,
+			GituiKeyEvent::new(
+				KeyCode::Char('h'),
+				KeyModifiers::NONE
+			)
+		);
 	}
 }
